@@ -11,7 +11,6 @@ use crate::axes3d::*;
 use crate::options::{GnuplotVersion, MultiplotFillDirection, MultiplotFillOrder};
 use crate::util::escape;
 use crate::writer::Writer;
-use std::cell::RefCell;
 use std::fs::File;
 use std::io::{BufWriter, Write};
 use std::path::{Path, PathBuf};
@@ -84,7 +83,42 @@ impl MultiplotOptions
 	}
 }
 
-/// A figure that may contain multiple axes
+/// A sentinel that represents a gnuplot waiting to close.
+pub struct CloseSentinel
+{
+	gnuplot: Child,
+}
+
+impl CloseSentinel
+{
+	fn new(gnuplot: Child) -> Self
+	{
+		CloseSentinel { gnuplot: gnuplot }
+	}
+
+	/// Waits until the gnuplot process exits. See `std::process::Child::wait`.
+	pub fn wait(&mut self) -> std::io::Result<std::process::ExitStatus>
+	{
+		self.gnuplot.wait()
+	}
+
+	/// Waits until the gnuplot process exits. See
+	/// `std::process::Child::try_wait`.
+	pub fn try_wait(&mut self) -> std::io::Result<Option<std::process::ExitStatus>>
+	{
+		self.gnuplot.try_wait()
+	}
+}
+
+impl Drop for CloseSentinel
+{
+	fn drop(&mut self)
+	{
+		self.wait().unwrap();
+	}
+}
+
+/// A figure that may contain multiple axes.
 pub struct Figure
 {
 	axes: Vec<AxesVariant>,
@@ -94,7 +128,7 @@ pub struct Figure
 	post_commands: String,
 	pre_commands: String,
 	// RefCell so that we can echo to it
-	gnuplot: RefCell<Option<Child>>,
+	gnuplot: Option<Child>,
 	version: Option<GnuplotVersion>,
 	multiplot_options: Option<MultiplotOptions>,
 }
@@ -109,7 +143,7 @@ impl Default for GnuplotVersion
 
 impl Figure
 {
-	/// Creates a new figure
+	/// Creates a new figure.
 	pub fn new() -> Figure
 	{
 		Figure {
@@ -117,7 +151,7 @@ impl Figure
 			terminal: "".into(),
 			enhanced_text: true,
 			output_file: None,
-			gnuplot: RefCell::new(None),
+			gnuplot: None,
 			post_commands: "".into(),
 			pre_commands: "".into(),
 			version: None,
@@ -142,7 +176,14 @@ impl Figure
 	pub fn set_terminal<'l>(&'l mut self, terminal: &str, output_file: &str) -> &'l mut Figure
 	{
 		self.terminal = terminal.into();
-		self.output_file = Some(output_file.into());
+		self.output_file = if output_file.is_empty()
+		{
+			None
+		}
+		else
+		{
+			Some(output_file.into())
+		};
 		self
 	}
 
@@ -297,7 +338,11 @@ impl Figure
 
 	/// Launch a gnuplot process, if it hasn't been spawned already by a call to
 	/// this function, and display the figure on it.
-	pub fn show(&mut self) -> Result<&mut Figure, GnuplotInitError>
+	///
+	/// Usually you should prefer using `show` instead. This method is primarily
+	/// useful when you wish to call this multiple times, e.g. to redraw an
+	/// existing plot window.
+	pub fn show_and_keep_running(&mut self) -> Result<&mut Figure, GnuplotInitError>
 	{
 		if self.axes.len() == 0
 		{
@@ -327,9 +372,9 @@ impl Figure
 			}
 		}
 
-		if self.gnuplot.borrow().is_none()
+		if self.gnuplot.is_none()
 		{
-			*self.gnuplot.borrow_mut() = Some(
+			self.gnuplot = Some(
 				Command::new("gnuplot")
 					.arg("-p")
 					.stdin(Stdio::piped())
@@ -340,15 +385,37 @@ impl Figure
 			);
 		}
 
-		self.gnuplot.borrow_mut().as_mut().map(|p| {
-			let stdin = p.stdin.as_mut().expect("No stdin!?");
-			self.echo(stdin);
-			stdin.flush();
-		});
+		{
+			let mut gnuplot = self.gnuplot.take();
+			gnuplot.as_mut().map(|p| {
+				let stdin = p.stdin.as_mut().expect("No stdin!?");
+				self.echo(stdin);
+				stdin.flush();
+			});
+			self.gnuplot = gnuplot;
+		}
 
 		Ok(self)
 	}
 
+	/// Launch a gnuplot process, if it hasn't been spawned already and
+	/// display the figure on it.
+	///
+	/// Unlike `show_and_keep_running`, this also instructs gnuplot to close if
+	/// you close all of the plot windows. You can use the returned
+	/// `CloseSentinel` to wait until this happens.
+	pub fn show(&mut self) -> Result<CloseSentinel, GnuplotInitError>
+	{
+		self.show_and_keep_running()?;
+		let mut gnuplot = self.gnuplot.take().expect("No gnuplot?");
+		{
+			let stdin = gnuplot.stdin.as_mut().expect("No stdin!?");
+			writeln!(stdin, "pause mouse close");
+			writeln!(stdin, "quit");
+		};
+		Ok(CloseSentinel::new(gnuplot))
+	}
+
 	/// Save the figure to a png file.
 	///
 	/// # Arguments
@@ -363,7 +430,7 @@ impl Figure
 		let former_output_file = self.output_file.clone();
 		self.terminal = format!("pngcairo size {},{}", width_px, height_px);
 		self.output_file = Some(filename.as_ref().into());
-		self.show()?.close();
+		self.show()?;
 		self.terminal = former_term;
 		self.output_file = former_output_file;
 
@@ -384,7 +451,7 @@ impl Figure
 		let former_output_file = self.output_file.clone();
 		self.terminal = format!("svg size {},{}", width_px, height_px);
 		self.output_file = Some(filename.as_ref().into());
-		self.show()?.close();
+		self.show()?;
 		self.terminal = former_term;
 		self.output_file = former_output_file;
 
@@ -405,7 +472,7 @@ impl Figure
 		let former_output_file = self.output_file.clone();
 		self.terminal = format!("pdfcairo size {},{}", width_in, height_in);
 		self.output_file = Some(filename.as_ref().into());
-		self.show()?.close();
+		self.show()?;
 		self.terminal = former_term;
 		self.output_file = former_output_file;
 
@@ -426,7 +493,7 @@ impl Figure
 		let former_output_file = self.output_file.clone();
 		self.terminal = format!("epscairo size {},{}", width_in, height_in);
 		self.output_file = Some(filename.as_ref().into());
-		self.show()?.close();
+		self.show()?;
 		self.terminal = former_term;
 		self.output_file = former_output_file;
 
@@ -447,7 +514,7 @@ impl Figure
 		let former_output_file = self.output_file.clone();
 		self.terminal = format!("canvas size {},{}", width_px, height_px);
 		self.output_file = Some(filename.as_ref().into());
-		self.show()?.close();
+		self.show()?;
 		self.terminal = former_term;
 		self.output_file = former_output_file;
 
@@ -460,22 +527,20 @@ impl Figure
 	/// that it was written.
 	pub fn close(&mut self) -> &mut Figure
 	{
-		if self.gnuplot.borrow().is_none()
+		if self.gnuplot.is_none()
 		{
 			return self;
 		}
 
 		{
-			let mut gnuplot = self.gnuplot.borrow_mut();
-
-			gnuplot.as_mut().map(|p| {
+			self.gnuplot.as_mut().map(|p| {
 				{
 					let stdin = p.stdin.as_mut().expect("No stdin!?");
 					writeln!(stdin, "quit");
 				}
 				p.wait();
 			});
-			*gnuplot = None;
+			self.gnuplot = None;
 		}
 
 		self
@@ -628,7 +693,7 @@ fn flush_test()
 	let mut fg = Figure::new();
 	fg.axes2d().boxes(0..5, 0..5, &[]);
 	fg.set_terminal("pngcairo", &*filename.to_string_lossy());
-	fg.show().unwrap().close();
+	fg.show();
 	fs::read(filename).unwrap();
 	fs::remove_dir_all(&tmp_path);
 }
