@@ -28,6 +28,7 @@ pub use crate::axes3d::Axes3D;
 pub use crate::axes_common::AxesCommon;
 pub use crate::coordinates::*;
 pub use crate::datatype::*;
+pub use crate::error_types::*;
 pub use crate::figure::*;
 pub use crate::options::*;
 
@@ -39,6 +40,7 @@ mod axes3d;
 mod axes_common;
 mod coordinates;
 mod datatype;
+mod error_types;
 mod figure;
 mod options;
 mod writer;
